# NEMOVIEW - Visualization tool for NEMO ensembles.


[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg?style=plastic)](https://www.python.org/)
[![license](https://img.shields.io/github/license/LeonardoESousa/nemoview?style=plastic)]()
[![maint](https://img.shields.io/maintenance/yes/2024?style=plastic)]()
[![down](https://img.shields.io/pypi/dm/nemoview?style=plastic)]()
[![commit](https://img.shields.io/github/last-commit/LeonardoESousa/nemoview?style=plastic)]()
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/LeonardoESousa/nemoview/HEAD?urlpath=voila%2Frender%2Fnemoview%2Fnemodash.ipynb)

## An application for analysis and visualization of results from NEMO ensemble calculations. 


<img src="Tutorial/Figures/nemoview_front.png" alt="Alt Text" width="2000">


## Quick Guide

1 - Try running it using  binder: [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/LeonardoESousa/nemoview/HEAD?urlpath=voila%2Frender%2Fnemoview%2Fnemodash.ipynb)

2 - Read the [tutorial](https://github.com/LeonardoESousa/nemoview/tree/main/Tutorial/Tutorial.md) while the application loads. 

3 - Examples of ensemble files for testing can be found [here](https://github.com/LeonardoESousa/nemoview/tree/main/Tutorial).

## How to install it?

The easiest way to install is to use pip:

`pip install nemoview`

This will install the latest released version.

To install the version with the latest commit, run:

`pip install git+https://github.com/LeonardoESousa/nemoview`

**NOTE**: It is recommended that you install **NEMOview** within a virtual enviroment.

## How to use it?

Once installed, use the command:

`nemoview`

The application will open in your browser.

## Tutorial

For details on the analyses available in **NEMOview**, check the [tutorial](https://github.com/LeonardoESousa/nemoview/tree/main/Tutorial/Tutorial.md).